# Model Format

Describe the format for the model (e.g. a SavedModel file for TF 2.0)

# Training Data

Describe the data that the model instance was trained on.

# Model Inputs

Describe the type and the shape of the model inputs.

# Model Outputs

Describe the type and the shape of the model outputs.

# Model Usage

Provide code snippets that demonstrate how to load and make use of the model instance.

# Fine-tuning

Provide code snippets that demonstrate how to fine-tune the model instance (if applicable).

# Changelog

Describe the differences between the different versions for this specific model instance (if applicable). 
